@@ -2,12 +2,12 @@
 #define _MQTT_H_
 
 #include <stdbool.h>
+
 #include "main.h"
+#include "types.h"
 
-struct call;
 struct call_media;
 
-
 #ifdef HAVE_MQTT
 
 
@@ -15,8 +15,8 @@ int mqtt_init(void);
 void mqtt_loop(void *);
 int mqtt_publish_scope(void);
 void mqtt_publish(char *);
-void mqtt_timer_run_media(struct call *, struct call_media *);
-void mqtt_timer_run_call(struct call *);
+void mqtt_timer_run_media(call_t *, struct call_media *);
+void mqtt_timer_run_call(call_t *);
 void mqtt_timer_run_global(void);
 void mqtt_timer_run_summary(void);
 
@@ -28,8 +28,8 @@ void mqtt_timer_run_summary(void);
 INLINE int mqtt_init(void) { return 0; }
 INLINE void mqtt_publish(char *s) { }
 INLINE int mqtt_publish_scope(void) { return MPS_NONE; };
-INLINE void mqtt_timer_run_media(struct call *c, struct call_media *m) { }
-INLINE void mqtt_timer_run_call(struct call *c) { }
+INLINE void mqtt_timer_run_media(call_t *c, struct call_media *m) { }
+INLINE void mqtt_timer_run_call(call_t *c) { }
 INLINE void mqtt_timer_run_global(void) { }
 INLINE void mqtt_timer_run_summary(void) { }
 
